@@ -19,8 +19,8 @@
 #ifndef KGAMERENDEREDITEM_H
 #define KGAMERENDEREDITEM_H
 
-#include <QtCore/QObject>
-#include <QtWidgets/QGraphicsItem>
+#include <QObject>
+#include <QGraphicsItem>
 
 #include <kgamerendererclient.h>
 #include <libkdegames_export.h>
@@ -44,7 +44,7 @@ class KDEGAMES_EXPORT KGameRenderedItem : public QGraphicsPixmapItem, public KGa
 		KGameRenderedItem(KGameRenderer* renderer, const QString& spriteKey, QGraphicsItem* parent = 0);
 		virtual ~KGameRenderedItem();
 	protected:
-		virtual void receivePixmap(const QPixmap& pixmap);
+		void receivePixmap(const QPixmap& pixmap) Q_DECL_OVERRIDE;
 	private:
 		friend class KGameRenderedItemPrivate;
 		KGameRenderedItemPrivate* const d;
