@@ -35,9 +35,9 @@ class KgThemeDelegate : public QStyledItemDelegate
 		};
 
 		KgThemeDelegate(QObject* parent = 0);
-		virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+		void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE;
 		///@note The implementation is independent of @a option and @a index.
-		virtual QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+		QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE;
 		QRect thumbnailRect(const QRect& baseRect) const;
 };
 
