@@ -21,12 +21,12 @@
 
 #include <kfilterdev.h>
 
-#include <QtCore/QBuffer>
-#include <QtCore/QFile>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtXml/QDomElement>
-#include <QtXml/QDomNode>
+#include <QBuffer>
+#include <QFile>
+#include <QString>
+#include <QStringList>
+#include <QDomElement>
+#include <QDomNode>
 #include <QDebug>
 
 #include <math.h>
@@ -148,7 +148,6 @@ KGameSvgDocument::KGameSvgDocument()
 KGameSvgDocument::KGameSvgDocument(const KGameSvgDocument &doc)
     : QDomDocument(), d(new KGameSvgDocumentPrivate(*doc.d))
 {
-    QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
 }
 
 KGameSvgDocument::~KGameSvgDocument()
